import _styled from 'styled-components';
import React, { useMemo } from 'react';
import { useViewport as me } from '../../../node_modules/.pnpm/use-viewport@0.2.0/node_modules/use-viewport/dist/index.js';
import PropTypes from '../../../node_modules/.pnpm/prop-types@15.7.2/node_modules/prop-types/index.js';
import Spacer from '../Spacer/Spacer.js';
import { RADIUS, GU } from '../../style/constants.js';
import { useTheme } from '../../theme/Theme2.js';
import IconThickCross from '../../icons/components/IconThickCross.js';
import IconInfo from '../../icons/components/IconInfo.js';
import { textStyle } from '../../style/text-styles.js';

function useModeColor(mode, withIcon) {
  const theme = useTheme();
  const {
    within
  } = me();
  const compactMode = within(-1, 'medium');

  if (mode === 'error') {
    return compactMode ? !withIcon ? `linear-gradient(123.23deg, #141C24 11.81%, #262A34 98.51%)` : `linear-gradient(270.07deg, rgba(27, 35, 49, 0) 0.04%, #1B2331 0.05%, #1B2331 80.37%, #690A0A 98.28%)` : `linear-gradient(270deg, #1B2331 36.46%, #3F0B0B 100%)`;
  }

  if (mode === 'warning') {
    return compactMode ? !withIcon ? `linear-gradient(123.23deg, #141C24 11.81%, #262A34 98.51%)` : `linear-gradient(90.02deg, #888632 0.02%, #0B1525 15.45%, #0B1525 99.43%)` : `linear-gradient(270deg, ${theme.surface} 36.46%, #816110 100%)`;
  }

  if (mode === 'info') {
    return compactMode ? !withIcon ? `linear-gradient(123.23deg, #141C24 11.81%, #262A34 98.51%)` : `linear-gradient(89.98deg, #104A64 1.52%, #1B2331 16.38%)` : `linear-gradient(270deg, ${theme.surface} 36.46%, #104A64 100%)`;
  }

  return `background: ${theme.surface}`;
}

function Banner(_ref) {
  let {
    children,
    mode = 'info',
    title,
    withIcon = true
  } = _ref;
  const modeBackground = useModeColor(mode, withIcon);
  const {
    within
  } = me();
  const theme = useTheme();
  const titleColor = useMemo(() => {
    if (mode === 'error') {
      return theme.negative;
    }

    if (mode === 'info') {
      return theme.accentAlternative;
    }

    if (mode === 'warning') {
      return theme.yellow;
    }
  }, [mode, theme]);
  const modeIcon = useMemo(() => {
    if (mode === 'error') {
      return /*#__PURE__*/React.createElement(IconThickCross, {
        size: "mini"
      });
    }

    if (mode === 'info') {
      return /*#__PURE__*/React.createElement(IconInfo, {
        size: "mini"
      });
    }

    if (mode === 'warning') {
      return /*#__PURE__*/React.createElement(IconInfo, {
        size: "mini"
      });
    }
  }, [mode]);
  const compactMode = within(-1, 'medium');
  return /*#__PURE__*/React.createElement(_StyledDiv, {
    $_css: 25 * GU,
    $_css2: modeBackground,
    $_css3: !withIcon ? '1fr' : compactMode ? `${3 * GU}px 1fr` : `${12 * GU}px 1fr`,
    $_css4: compactMode ? `${GU * 2}px` : `${3 * GU}px ${4 * GU}px`
  }, withIcon && /*#__PURE__*/React.createElement(_StyledDiv2, {
    $_css5: compactMode ? 2 * GU : 12 * GU,
    $_css6: compactMode ? 'start' : 'center',
    $_css7: compactMode ? 2 * GU : 0
  }, /*#__PURE__*/React.createElement(_StyledDiv3, {
    $_css8: compactMode ? 'transparent' : titleColor,
    $_css9: compactMode ? 2 * GU : 4 * GU,
    $_css10: compactMode ? 1.5 * GU : 4 * GU,
    $_css11: compactMode && `2px solid ${titleColor}`,
    $_css12: compactMode && `svg {
                color ${titleColor};
                width: ${GU}px;
                height: ${GU}px;
              }`
  }, modeIcon)), /*#__PURE__*/React.createElement(_StyledDiv4, null, /*#__PURE__*/React.createElement(_StyledH, {
    $_css13: textStyle('title3'),
    $_css14: titleColor,
    $_css15: compactMode ? '0' : '16',
    $_css16: compactMode ? '0' : '16'
  }, title), /*#__PURE__*/React.createElement(Spacer, {
    size: 2 * GU
  }), /*#__PURE__*/React.createElement(_StyledP, {
    $_css17: textStyle('body3'),
    $_css18: compactMode ? '0' : '16',
    $_css19: compactMode ? '0' : '16',
    $_css20: theme.content
  }, children)));
}

Banner.propTypes = {
  children: PropTypes.node,
  mode: PropTypes.string,
  title: PropTypes.string,
  withIcon: PropTypes.bool
};

var _StyledDiv = _styled("div").withConfig({
  displayName: "Banner___StyledDiv",
  componentId: "sc-18dlyao-0"
})(["width:100%;min-height:", ";background:", ";display:grid;grid-template-columns:", ";padding:", ";border-radius:", "px;"], p => p.$_css, p => p.$_css2, p => p.$_css3, p => p.$_css4, RADIUS);

var _StyledDiv2 = _styled("div").withConfig({
  displayName: "Banner___StyledDiv2",
  componentId: "sc-18dlyao-1"
})(["width:", "px;height:100%;display:flex;justify-content:center;align-items:", ";margin-top:", "px;"], p => p.$_css5, p => p.$_css6, p => p.$_css7);

var _StyledDiv3 = _styled("div").withConfig({
  displayName: "Banner___StyledDiv3",
  componentId: "sc-18dlyao-2"
})(["background:", ";width:", "px;height:", "px;border-radius:50% 50%;display:flex;justify-content:center;align-items:center;border:", ";", ""], p => p.$_css8, p => p.$_css9, p => p.$_css10, p => p.$_css11, p => p.$_css12);

var _StyledDiv4 = _styled("div").withConfig({
  displayName: "Banner___StyledDiv4",
  componentId: "sc-18dlyao-3"
})(["width:100%;height:100%;display:flex;flex-direction:column;"]);

var _StyledH = _styled("h2").withConfig({
  displayName: "Banner___StyledH",
  componentId: "sc-18dlyao-4"
})(["", " font-weight:bold;color:", ";margin-bottom:", "px;margin-top:", "px;"], p => p.$_css13, p => p.$_css14, p => p.$_css15, p => p.$_css16);

var _StyledP = _styled("p").withConfig({
  displayName: "Banner___StyledP",
  componentId: "sc-18dlyao-5"
})(["", ";margin-bottom:", "px;margin-top:", "px;color:", ";"], p => p.$_css17, p => p.$_css18, p => p.$_css19, p => p.$_css20);

export { Banner as default };
//# sourceMappingURL=Banner.js.map
